@@ -10,6 +10,10 @@
 #include <freeradius/ident.h>
 RCSIDH(detail_h, "$Id$")
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 typedef enum detail_state_t {
   STATE_UNOPENED = 0,
   STATE_UNLOCKED,
@@ -39,6 +43,7 @@ typedef struct listen_detail_t {
 	int		retry_interval;
 	int		packets;
 	int		tries;
+	int		one_shot;
 
 	int		has_rtt;
 	int		srtt;
@@ -56,4 +61,8 @@ int detail_encode(UNUSED rad_listen_t *this, UNUSED REQUEST *request);
 int detail_decode(UNUSED rad_listen_t *this, UNUSED REQUEST *request);
 int detail_parse(CONF_SECTION *cs, rad_listen_t *this);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* DETAIL_H */
