@@ -45,6 +45,7 @@
 #define PW_AUTH_UDP_PORT                1812
 #define PW_ACCT_UDP_PORT                1813
 #define PW_POD_UDP_PORT			1700
+#define PW_COA_UDP_PORT			3799
 
 #define	PW_USER_NAME			1
 #define	PW_USER_PASSWORD		2
@@ -126,6 +127,7 @@
 #define PW_DIGEST_ATTRIBUTES		207
 
 #define PW_FALL_THROUGH			500
+#define PW_RELAX_FILTER			501
 #define PW_EXEC_PROGRAM			502
 #define PW_EXEC_PROGRAM_WAIT		503
 
@@ -200,6 +202,7 @@
 #define PW_RESPONSE_PACKET_TYPE		1080
 #define PW_DIGEST_HA1			1081
 #define PW_MS_CHAP_USE_NTLM_AUTH	1082
+#define PW_MS_CHAP_USER_NAME		1083
 #define PW_PACKET_SRC_IP_ADDRESS	1084
 #define PW_PACKET_DST_IP_ADDRESS	1085
 #define PW_PACKET_SRC_PORT		1086
@@ -220,8 +223,19 @@
 #define PW_VIRTUAL_SERVER		1099
 #define PW_CLEARTEXT_PASSWORD		1100
 #define PW_PASSWORD_WITH_HEADER		1101
+#define PW_SEND_COA_REQUEST		1107
 #define PW_MODULE_RETURN_CODE		1108
 #define PW_PACKET_ORIGINAL_TIMESTAMP   	1109
+#define PW_HOME_SERVER_POOL		1111
+#define PW_RECV_COA_TYPE   		1131
+#define PW_SEND_COA_TYPE   		1132
+#define PW_MSCHAP_PASSWORD		1133
+#define PW_PACKET_TRANSMIT_COUNTER     	1134
+#define PW_CACHED_SESSION_POLICY     	1135
+
+#define PW_CACHE_TTL			1140
+#define PW_CACHE_STATUS_ONLY		1141
+#define PW_CACHE_ENTRY_HITS		1142
 
 /*
  *	Integer Translations
