@@ -599,7 +599,8 @@ int            radius_xlat(char * out, int outlen, const char *fmt,
 typedef size_t (*RAD_XLAT_FUNC)(void *instance, REQUEST *, char *, char *, size_t, RADIUS_ESCAPE_STRING func);
 int		xlat_register(const char *module, RAD_XLAT_FUNC func,
 			      void *instance);
-void		xlat_unregister(const char *module, RAD_XLAT_FUNC func);
+void		xlat_unregister(const char *module, RAD_XLAT_FUNC func,
+				void *instance);
 void		xlat_free(void);
 
 /* threads.c */
