@@ -11,6 +11,10 @@ RCSIDH(udpfromtoh, "$Id$")
 #include <freeradius/autoconf.h>
 #include <freeradius/libradius.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #ifdef WITH_UDPFROMTO
 int udpfromto_init(int s);
 int recvfromto(int s, void *buf, size_t len, int flags,
@@ -21,4 +25,8 @@ int sendfromto(int s, void *buf, size_t len, int flags,
 	       struct sockaddr *to, socklen_t tolen);
 #endif
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
