@@ -10,6 +10,10 @@
 #include <freeradius/ident.h>
 RCSIDH(vmps_h, "$Id$")
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 int vqp_socket_recv(rad_listen_t *listener,
 		    RAD_REQUEST_FUNP *pfun, REQUEST **prequest);
 int vqp_socket_send(rad_listen_t *listener, REQUEST *request);
@@ -17,4 +21,8 @@ int vqp_socket_encode(UNUSED rad_listen_t *listener, REQUEST *request);
 int vqp_socket_decode(UNUSED rad_listen_t *listener, REQUEST *request);
 int vmps_process(REQUEST *request);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* VMPS_H */
